@@ -12,11 +12,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from __future__ import print_function
 import argparse
 import collections
+import logging
 import os
 import sys
 
+import diskimage_builder.logging_config
+
+logger = logging.getLogger(__name__)
+
 
 def get_elements_dir():
     if not os.environ.get('ELEMENTS_PATH'):
@@ -41,9 +47,8 @@ def _get_set(element, fname, elements_dir=None):
             else:
                 raise
 
-    sys.stderr.write("ERROR: Element '%s' not found in '%s'\n" %
-                     (element, elements_dir))
-    exit(-1)
+    logger.error("Element '%s' not found in '%s'" % (element, elements_dir))
+    sys.exit(-1)
 
 
 def provides(element, elements_dir=None):
@@ -98,28 +103,36 @@ def expand_dependencies(user_elements, elements_dir=None):
         check_queue.extend(deps - (final_elements | provided))
         final_elements.update(deps)
 
+    if "operating-system" not in provided:
+        logger.error(
+            "Please include an operating system element.")
+        sys.exit(-1)
+
     conflicts = set(user_elements) & provided
     if conflicts:
-        sys.stderr.write("ERROR: Following elements were explicitly required "
-                         "but are provided by other included elements: %s\n" %
-                         ", ".join(conflicts))
-        exit(-1)
+        logger.error("Following elements were explicitly required "
+                     "but are provided by other included elements: %s" %
+                     ", ".join(conflicts))
+        sys.exit(-1)
     return final_elements - provided
 
 
 def main(argv):
+    diskimage_builder.logging_config.setup()
+
     parser = argparse.ArgumentParser()
     parser.add_argument('elements', nargs='+',
-                        help='elements to inspect')
+                        help='display dependencies of the given elements')
     parser.add_argument('--expand-dependencies', '-d', action='store_true',
                         default=False,
-                        help='Print expanded dependencies of all args')
+                        help=('(DEPRECATED) print expanded dependencies '
+                              'of all args'))
 
     args = parser.parse_args(argv[1:])
 
     if args.expand_dependencies:
-        print(' '.join(expand_dependencies(args.elements)))
-        return 0
+        logger.warning("expand-dependencies flag is deprecated,  "
+                       "and is now on by default.", file=sys.stderr)
 
-    sys.stderr.write("ERROR: please choose an option.\n")
-    return -1
+    print(' '.join(expand_dependencies(args.elements)))
+    return 0
